================================================================================
snapshot-phantomjs
================================================================================

.. image:: https://api.travis-ci.org/pyecharts/snapshot-phantomjs.svg
   :target: http://travis-ci.org/pyecharts/snapshot-phantomjs

.. image:: https://codecov.io/github/pyecharts/snapshot-phantomjs/coverage.png
   :target: https://codecov.io/github/pyecharts/snapshot-phantomjs


.. image:: https://readthedocs.org/projects/snapshot-phantomjs/badge/?version=latest
   :target: http://snapshot-phantomjs.readthedocs.org/en/latest/


Installation
================================================================================


You can install snapshot-phantomjs via pip:

.. code-block:: bash

    $ pip install snapshot-phantomjs


or clone it and install it:

.. code-block:: bash

    $ git clone https://github.com/pyecharts/snapshot-phantomjs.git
    $ cd snapshot-phantomjs
    $ python setup.py install
